@@ -21,7 +21,7 @@ def set_array(obj, prop, value):
         value = empty(0)
     elif isinstance(value, list):
         value = array(value)
-    setattr(obj, prop, squeeze(value))
+    setattr(obj, prop, value)
 
 
 def check_init_dict(init_dict, key_list):
@@ -345,9 +345,9 @@ def check_dimensions(values, axes):
         Dimensions of field and axes do not match
     """
     if isinstance(values, list):
-        values = squeeze(array(values))
+        values = array(values)
     else:
-        values = squeeze(values)
+        values = values
 
     values_shape = values.shape
     axes_shape = []
